@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -124,6 +124,8 @@ void SKGStatisticPlugin::refresh()
                 m_stats[QStringLiteral("current.app_version")] = KAboutData::applicationData().version();
                 m_stats[QStringLiteral("current.language")] = QLocale::languageToString(QLocale().language());
                 m_stats[QStringLiteral("current.country")] = QLocale::countryToString(QLocale().country());
+                m_stats[QStringLiteral("current.country.code")] = QLocale().name().split("_").at(0);
+                m_stats[QStringLiteral("current.locale")] = QLocale().name();
 
                 // OS
 #ifdef Q_OS_WIN32
