@@ -209,11 +209,11 @@ class Releasor(object):
                                 f = open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/debian/control'), 'r')
                                 cf = f.read()
                                 f.close()
-                                  
-                                print('#   make changes for '+self.ubuntuVersions[i])
-                                f = open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/debian/control'), 'w')
-                                f.write(cf.replace('libqjson-dev, \n', '').replace('libqjson0, ', ''))
-                                f.close()                                 
+                                
+                                #print('#   make changes for '+self.ubuntuVersions[i])
+                                #f = open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/debian/control'), 'w')
+                                #f.write(cf.replace('libqjson-dev, \n', '').replace('libqjson0, ', ''))
+                                #f.close()                                 
                                     
                                 with open(os.path.join(self.workdingDir, 'skrooge-'+args.version+'/debian/changelog'), 'w') as fileDebianChangelog:
                                     fileDebianChangelog.write('skrooge ('+args.version+'-0ubuntu1~'+ppa+str(i+1)+') '+self.ubuntuVersions[i]+'; urgency=medium\n')
@@ -283,8 +283,9 @@ class Releasor(object):
         self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)       
         if rc == 0:
-            #for line in fileinput.input(['pkg2appimage'], inplace=True):
-            #    print(line.replace('trusty', 'bionic').replace('xenial', 'bionic'), end='')
+            for line in fileinput.input(['pkg2appimage'], inplace=True):
+                if(not 'libcurl-slim' in line):
+                    print(line, end='')
                 
             os.chmod('./pkg2appimage', 0o775)
                 
