@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -917,7 +917,11 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                     toolTipString += '\n';
                     toolTipString += i18nc("A tool tip", "You can use the reconciliation mode to validate pointed operations.");
                     toolTipString += '\n';
-                    toolTipString += i18nc("A tool tip", "Click to switch back status.");
+                    if (att == QStringLiteral("t_status")) {
+                        toolTipString += i18nc("A tool tip", "Click in this column to switch back status.");
+                    } else {
+                        toolTipString += i18nc("A tool tip", "Click in the Status (checkmark) column to switch back status.");
+                    }
                     toolTipString += '\n';
                     toolTipString += i18nc("A tool tip", "Ctrl+click to force checked status.");
                 } else if (op.getStatus() == SKGOperationObject::CHECKED) {
@@ -1122,9 +1126,6 @@ Qt::DropActions SKGObjectModel::supportedDragActions() const
 
 Qt::DropActions SKGObjectModel::supportedDropActions() const
 {
-    if (m_categoryTable || m_payeeTable || m_accountTable || m_unitTable || m_trackerTable) {
-        return Qt::MoveAction;
-    }
     return SKGObjectModelBase::supportedDropActions();
 }
 
