@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
+ *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -810,6 +810,50 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true)
         }
     }
+
+    {
+        // Test import BUG 420557
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err)
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/420557_1.csv"));
+            QMap<QString, QString> parameters = imp1.getImportParameters();
+            parameters[QStringLiteral("automatic_search_columns")] = 'N';
+            parameters[QStringLiteral("header_position")] = QStringLiteral("1");
+            parameters[QStringLiteral("columns_positions")] = QStringLiteral("date|account|idgroup|idtransaction|value|unit");
+            imp1.setImportParameters(parameters);
+            SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true)
+        }
+
+        int nb = 0;
+        SKGTESTERROR(QStringLiteral("OPERATION.getNbObjects"), document1.getNbObjects(QStringLiteral("operation"), QStringLiteral("i_group_id=1"), nb), true)
+        SKGTEST(QStringLiteral("OPERATION:nb"), nb, 2)
+    }
+
+    {
+        // Test import BUG 420557
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true)
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err)
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/420557_2.csv"));
+            QMap<QString, QString> parameters = imp1.getImportParameters();
+            parameters[QStringLiteral("automatic_search_columns")] = 'N';
+            parameters[QStringLiteral("header_position")] = QStringLiteral("1");
+            parameters[QStringLiteral("columns_positions")] = QStringLiteral("date|account|idgroup|idtransaction|value|unit");
+            imp1.setImportParameters(parameters);
+            SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true)
+        }
+
+        int nb = 0;
+        SKGTESTERROR(QStringLiteral("OPERATION.getNbObjects"), document1.getNbObjects(QStringLiteral("operation"), QStringLiteral("i_group_id=1"), nb), true)
+        SKGTEST(QStringLiteral("OPERATION:nb"), nb, 2)
+    }
     // End test
     SKGENDTEST()
 }  // NOLINT(readability/fn_size)
